==> haskell-success-0.2.6-38-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-success.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: success
version: 0.2.6
id: success-0.2.6-IbCsmeeDaHhDBCOOl7Nwxs
key: success-0.2.6-IbCsmeeDaHhDBCOOl7Nwxs
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/success
synopsis: A version of Either specialised for encoding of success or failure
description:
    The primary motivation for creation of this package was the need
    for the '\''Alternative'\'' instance of '\''Either'\'',
    which there is no sane way to implement.
    The type provided by this library extends '\''Either'\'' in a way to provide the missing instance.
category: Data, Failure
abi: 1ffb8611849128c0dfc71fea121dfa71
exposed: True
exposed-modules:
    Success.Impure Success.Pure
import-dirs: /usr/lib/ghc-8.6.4/site-local/success-0.2.6
library-dirs: /usr/lib/ghc-8.6.4/site-local/success-0.2.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/success-0.2.6
hs-libraries: HSsuccess-0.2.6-IbCsmeeDaHhDBCOOl7Nwxs
depends:
    base-4.12.0.0 monad-control-1.0.2.3-8d9BFLxdv0m5ZddAp98CYo
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-CiZEid5DnKxKMvWGI9SJsd
haddock-interfaces: /usr/share/doc/haskell-success/html/success.haddock
haddock-html: /usr/share/doc/haskell-success/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-success-0.2.6-39-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-success.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: success
version: 0.2.6
id: success-0.2.6-IVGlDlKT4vH1JFNTzOw8Vz
key: success-0.2.6-IVGlDlKT4vH1JFNTzOw8Vz
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/success
synopsis: A version of Either specialised for encoding of success or failure
description:
    The primary motivation for creation of this package was the need
    for the '\''Alternative'\'' instance of '\''Either'\'',
    which there is no sane way to implement.
    The type provided by this library extends '\''Either'\'' in a way to provide the missing instance.
category: Data, Failure
abi: 60293cf922a27e71f32bd4b35a85764c
exposed: True
exposed-modules:
    Success.Impure Success.Pure
import-dirs: /usr/lib/ghc-8.6.4/site-local/success-0.2.6
library-dirs: /usr/lib/ghc-8.6.4/site-local/success-0.2.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/success-0.2.6
hs-libraries: HSsuccess-0.2.6-IVGlDlKT4vH1JFNTzOw8Vz
depends:
    base-4.12.0.0 monad-control-1.0.2.3-Je5cQkaSgr2JmPAbRE8UQ1
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-Krd41HMX2GqKs5tsLMKb7a
haddock-interfaces: /usr/share/doc/haskell-success/html/success.haddock
haddock-html: /usr/share/doc/haskell-success/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
